==> wormux-0.7.9.tar.gz: wormux-0.7.9/src/character/body_list.h <==
/******************************************************************************
 *  Wormux is a convivial mass murder game.
 *  Copyright (C) 2001-2004 Lawrence Azzoug.
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA
 ******************************************************************************
 *****************************************************************************/

#ifndef BODY_LIST_H
#define BODY_LIST_H
//-----------------------------------------------------------------------------
#include <SDL.h>
#include "body.h"
#include "../include/base.h"
#include "../tool/xml_document.h"
#include "../tool/resource_manager.h"
#include <map>
#include <string>
//-----------------------------------------------------------------------------
class Body;

class BodyList
{
  std::map<std::string, Body*> list;

  void Load (const std::string &name);

public:
  BodyList();
  void FreeMem();
  Body* GetBody(const std::string &body);
};

extern BodyList body_list;

//-----------------------------------------------------------------------------
#endif

==> wormux_0.8.orig.tar.gz: wormux-0.8/src/character/body_list.h <==
/******************************************************************************
 *  Wormux is a convivial mass murder game.
 *  Copyright (C) 2001-2008 Wormux Team.
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA
 ******************************************************************************
 *****************************************************************************/

#ifndef BODY_LIST_H
#define BODY_LIST_H
//-----------------------------------------------------------------------------
#include "include/base.h"
#include <map>
#include <string>
//-----------------------------------------------------------------------------
class Body;

class BodyList
{
  std::map<std::string, Body*> list;

  void Load (const std::string &name);

public:
  BodyList();
  void FreeMem();
  Body* GetBody(const std::string &body);
};

extern BodyList body_list;

//-----------------------------------------------------------------------------
#endif
